/****************************************************************/
/* SETUP                                                        */
/****************************************************************/
/* This driver has been tested with DAC8581 EVM, HPA-MCU EVM and*/
/* the TMS320F2808 eZdsp using Code Composer Studio v3.1        */
/*                                                              */
/* HARDWARE SETTINGS                                            */
/*                                                              */
/* F2808eZdsp:                                                  */
/*  - Solder a pinheader socket to P8; solder side is top side! */
/*  - on JP4 connect B to C (see also schematics)               */
/*                                                              */
/* DAC8581 EVM:                                                 */
/*  Jumper settings: (not mentioned jumper are "don't care")    */
/*    W1 (2-3), W4 (1-2), W5 (1-2), W14 (2-3), W15 (closed),    */
/*    W16 (open)                                                */
/*    J3 (2-3), J4.1-J4.2 (closed), J6.4-J6.5 (closed)          */
/*  Cable connections:                                          */
/*    -probe the analog signal on TP3                           */
/*                                                              */
/* HPA-MCU board:                                               */
/*  - Solder a zero Ohm resistor (bridge) on R7                 */
/*  - Connect +5V to J7                                         */
/*                                                              */
/* connect DAC8581 EVM to header J6, J12, JP6, on HPA-MCU EVM   */
/****************************************************************/
#include <math.h>

#include "DSP280x_Device.h"     // DSP280x Headerfile Include File
#include "dc_conf.h"
#include "t8581_fn.h"

#define BUFF_SZ (1024)

void TransferFinished(void* ptr);

int Buffer[BUFF_SZ];
volatile int iSemaphore = 0;

void main(void)
{
unsigned int i;

   	InitSysCtrl();
   	DINT;

	IER = 0x0000;
   	IFR = 0x0000;
   	InitPieCtrl();
   	InitPieVectTable();

	EINT;

	/* generated sine waves                                     */
	for (i = 0; i < BUFF_SZ;i++) {
     	Buffer[i] = (int)(sin(2 * 3.141592659 * i / BUFF_SZ) * 32767.0);
	}
		
	if (dc_configure(&Dac8581_1) != TIDC_NO_ERR) {
		dc_close(&Dac8581_1);
		abort();
	}
    
    /* send mid value                                           */
    (void)dc_writesample(&Dac8581_1, 0x00000000u);

    /* send buffer twice                                        */
    (void)dc_writeblock(&Dac8581_1, Buffer, BUFF_SZ, TransferFinished);
    iSemaphore++;
    (void)dc_writeblock(&Dac8581_1, Buffer, BUFF_SZ, TransferFinished);
    iSemaphore++;
	while(iSemaphore > 0);
    /* send buffer                                              */
    (void)dc_writeblock(&Dac8581_1, Buffer, BUFF_SZ, TransferFinished);
    iSemaphore++;
	while(iSemaphore > 0);

    /* send mid value                                           */
    (void)dc_writesample(&Dac8581_1, 0x00000000u);

    /* send buffer                                              */
    (void)dc_writeblock(&Dac8581_1, Buffer, BUFF_SZ, TransferFinished);
    iSemaphore++;
	while(iSemaphore > 0);

	/* free all by the software allocate resources              */
	dc_close(&Dac8581_1);

	/* allocate resources and put converter in power down mode  */
	if (dc_configure(&Dac8581_1) != TIDC_NO_ERR) {
		dc_close(&Dac8581_1);	
		abort();
	}

    (void)dc_writeblock(&Dac8581_1, Buffer, BUFF_SZ, TransferFinished);
    iSemaphore++;
	while(iSemaphore > 0);

	/* free all by the software allocate resources              */
	dc_close(&Dac8581_1);

    /* wait here forever ...                                    */
    while(1);
}

void TransferFinished(void* ptr)
{
 	iSemaphore--;
}
